@@ -16,9 +16,9 @@ import datetime
 import http.client as http_client
 import json
 import os
+from unittest import mock
 import urllib
 
-import mock
 import pytest  # type: ignore
 
 from google.auth import _helpers
