@@ -1,4 +1,5 @@
-import mock
+from unittest import mock
+
 import pytest  # type: ignore
 
 from google.oauth2 import webauthn_handler
