@@ -17,9 +17,9 @@ import datetime
 import http.client as http_client
 import json
 import os
+from unittest import mock
 import urllib
 
-import mock
 from OpenSSL import crypto
 import pytest  # type: ignore
 
@@ -38,8 +38,10 @@ SERVICE_ACCOUNT_EMAIL = "service-1234@service-name.iam.gserviceaccount.com"
 SERVICE_ACCOUNT_IMPERSONATION_URL_BASE = (
     "https://us-east1-iamcredentials.googleapis.com"
 )
-SERVICE_ACCOUNT_IMPERSONATION_URL_ROUTE = "/v1/projects/-/serviceAccounts/{}:generateAccessToken".format(
-    SERVICE_ACCOUNT_EMAIL
+SERVICE_ACCOUNT_IMPERSONATION_URL_ROUTE = (
+    "/v1/projects/-/serviceAccounts/{}:generateAccessToken".format(
+        SERVICE_ACCOUNT_EMAIL
+    )
 )
 SERVICE_ACCOUNT_IMPERSONATION_URL = (
     SERVICE_ACCOUNT_IMPERSONATION_URL_BASE + SERVICE_ACCOUNT_IMPERSONATION_URL_ROUTE
@@ -1051,7 +1053,6 @@ class TestCredentials(object):
     def test_retrieve_subject_token_certificate_trust_chain_invalid_order(
         self, mock_get_workload_cert_and_key_paths
     ):
-
         credentials = self.make_credentials(
             credential_source=self.CREDENTIAL_SOURCE_CERTIFICATE_TRUST_CHAIN_WRONG_ORDER
         )
@@ -1070,7 +1071,6 @@ class TestCredentials(object):
     def test_retrieve_subject_token_certificate_trust_chain_file_does_not_exist(
         self, mock_get_workload_cert_and_key_paths
     ):
-
         credentials = self.make_credentials(
             credential_source={
                 "certificate": {
@@ -1092,7 +1092,6 @@ class TestCredentials(object):
     def test_retrieve_subject_token_certificate_invalid_trust_chain_file(
         self, mock_get_workload_cert_and_key_paths
     ):
-
         credentials = self.make_credentials(
             credential_source={
                 "certificate": {
@@ -1785,7 +1784,7 @@ class TestCredentials(object):
     @mock.patch.object(
         identity_pool.Credentials, "_get_cert_bytes", return_value=b"cert"
     )
-    @mock.patch.object(external_account.Credentials, "_refresh_token")
+    @mock.patch.object(external_account.Credentials, "_perform_refresh_token")
     def test_refresh_with_agent_identity(
         self,
         mock_refresh_token,
@@ -1812,7 +1811,7 @@ class TestCredentials(object):
     @mock.patch.object(
         identity_pool.Credentials, "_get_cert_bytes", return_value=b"cert"
     )
-    @mock.patch.object(external_account.Credentials, "_refresh_token")
+    @mock.patch.object(external_account.Credentials, "_perform_refresh_token")
     def test_refresh_with_agent_identity_opt_out_or_not_agent(
         self,
         mock_refresh_token,
